<?php

namespace LakeDrops\DorgFlow;

use Composer\Composer;
use Composer\EventDispatcher\EventSubscriberInterface;
use Composer\IO\IOInterface;
use Composer\Plugin\PluginInterface;
use Composer\Script\Event;
use Composer\Script\ScriptEvents;

/**
 * Composer plugin for preparing Drupal project for development with dorgflow.
 */
class Plugin implements PluginInterface, EventSubscriberInterface {

  /**
   * The handler object to configure the project for dorgflow.
   *
   * @var \LakeDrops\DorgFlow\Handler
   */
  protected $handler;

  /**
   * {@inheritdoc}
   */
  public function activate(Composer $composer, IOInterface $io) {
    $this->handler = new Handler($composer, $io);
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return array(
      ScriptEvents::POST_INSTALL_CMD => 'prepareDevProjects',
      ScriptEvents::POST_UPDATE_CMD => 'prepareDevProjects',
    );
  }

  /**
   * Post install/update event callback.
   *
   * @param \Composer\Script\Event $event
   *   The event that triggered the call of this function.
   */
  public function prepareDevProjects(Event $event) {
    $this->handler->prepareDevProjects($event);
  }

  /**
   * Script callback for putting in composer scripts to prepare the project.
   *
   * @param \Composer\Script\Event $event
   *   The event that triggered the call of this function.
   */
  public static function prepare(Event $event) {
    $handler = new Handler($event->getComposer(), $event->getIO());
    $handler->prepareDevProjects($event);
  }

}
